@@ -1,4 +1,4 @@
-from .compat import basestring
+from .compat import basestring, numeric_types
 
 
 def _split_params_and_files(params_):
@@ -7,7 +7,7 @@ def _split_params_and_files(params_):
     for k, v in params_.items():
         if hasattr(v, 'read') and callable(v.read):
             files[k] = v
-        elif isinstance(v, basestring):
+        elif isinstance(v, basestring) or isinstance(v, numeric_types):
             params[k] = v
         elif isinstance(v, bool):
             params[k] = 'true' if v else 'false'
